@@ -29,8 +29,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
-#include <limits.h>
-#include <math.h>
 
 #include "filter.h"
 #include "libinput-util.h"
