@@ -23,8 +23,6 @@
 
 #include "config.h"
 
-#include <errno.h>
-#include <fcntl.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <libudev.h>
