@@ -27,8 +27,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <unistd.h>
-#include <fcntl.h>
 
 #include "evdev.h"
 #include "udev-seat.h"
