@@ -47,15 +47,6 @@ static int events[] = {
 	-1, -1,
 };
 
-static const char udev_rule[] =
-"ACTION==\"remove\", GOTO=\"switch_end\"\n"
-"KERNEL!=\"event*\", GOTO=\"switch_end\"\n"
-"\n"
-"ATTRS{name}==\"litest HP WMI hotkeys*\",\\\n"
-"    ENV{ID_INPUT_SWITCH}=\"1\"\n"
-"\n"
-"LABEL=\"switch_end\"";
-
 TEST_DEVICE("wmi-hotkeys",
 	.type = LITEST_HP_WMI_HOTKEYS,
 	.features = LITEST_SWITCH,
@@ -66,5 +57,8 @@ TEST_DEVICE("wmi-hotkeys",
 	.events = events,
 	.absinfo = NULL,
 
-	.udev_rule = udev_rule,
+	.udev_properties = {
+		{ "ID_INPUT_SWITCH", "1" },
+		{ NULL },
+	}
 )
