@@ -81,9 +81,9 @@ struct litest_test_device {
 };
 
 struct litest_device_interface {
-	void (*touch_down)(struct litest_device *d, unsigned int slot, double x, double y);
-	void (*touch_move)(struct litest_device *d, unsigned int slot, double x, double y);
-	void (*touch_up)(struct litest_device *d, unsigned int slot);
+	bool (*touch_down)(struct litest_device *d, unsigned int slot, double x, double y);
+	bool (*touch_move)(struct litest_device *d, unsigned int slot, double x, double y);
+	bool (*touch_up)(struct litest_device *d, unsigned int slot);
 
 	/**
 	 * Default value for the given EV_ABS axis.
