@@ -760,6 +760,84 @@ START_TEST(timer_flush)
 }
 END_TEST
 
+START_TEST(udev_absinfo_override)
+{
+	struct litest_device *dev = litest_current_device();
+	struct libevdev *evdev = dev->evdev;
+	const struct input_absinfo *abs;
+	struct udev_device *ud;
+	struct udev_list_entry *entry;
+	bool found_x = false, found_y = false,
+	     found_mt_x = false, found_mt_y = false;
+
+	ud = libinput_device_get_udev_device(dev->libinput_device);
+	ck_assert_notnull(ud);
+
+	/* Custom checks for this special litest device only */
+
+	entry = udev_device_get_properties_list_entry(ud);
+	while (entry) {
+		const char *key, *value;
+
+		key = udev_list_entry_get_name(entry);
+		value = udev_list_entry_get_value(entry);
+
+		if (streq(key, "EVDEV_ABS_00")) {
+			found_x = true;
+			ck_assert(streq(value, "1:1000:100:10"));
+		}
+		if (streq(key, "EVDEV_ABS_01")) {
+			found_y = true;
+			ck_assert(streq(value, "2:2000:200:20"));
+		}
+		if (streq(key, "EVDEV_ABS_35")) {
+			found_mt_x = true;
+			ck_assert(streq(value, "3:3000:300:30"));
+		}
+		if (streq(key, "EVDEV_ABS_36")) {
+			found_mt_y = true;
+			ck_assert(streq(value, "4:4000:400:40"));
+		}
+
+		entry = udev_list_entry_get_next(entry);
+	}
+	udev_device_unref(ud);
+
+	ck_assert(found_x);
+	ck_assert(found_y);
+	ck_assert(found_mt_x);
+	ck_assert(found_mt_y);
+
+	abs = libevdev_get_abs_info(evdev, ABS_X);
+	ck_assert_int_eq(abs->minimum, 1);
+	ck_assert_int_eq(abs->maximum, 1000);
+	ck_assert_int_eq(abs->resolution, 100);
+	/* if everything goes well, we override the fuzz to 0 */
+	ck_assert_int_eq(abs->fuzz, 0);
+
+	abs = libevdev_get_abs_info(evdev, ABS_Y);
+	ck_assert_int_eq(abs->minimum, 2);
+	ck_assert_int_eq(abs->maximum, 2000);
+	ck_assert_int_eq(abs->resolution, 200);
+	/* if everything goes well, we override the fuzz to 0 */
+	ck_assert_int_eq(abs->fuzz, 0);
+
+	abs = libevdev_get_abs_info(evdev, ABS_MT_POSITION_X);
+	ck_assert_int_eq(abs->minimum, 3);
+	ck_assert_int_eq(abs->maximum, 3000);
+	ck_assert_int_eq(abs->resolution, 300);
+	/* if everything goes well, we override the fuzz to 0 */
+	ck_assert_int_eq(abs->fuzz, 0);
+
+	abs = libevdev_get_abs_info(evdev, ABS_MT_POSITION_Y);
+	ck_assert_int_eq(abs->minimum, 4);
+	ck_assert_int_eq(abs->maximum, 4000);
+	ck_assert_int_eq(abs->resolution, 400);
+	/* if everything goes well, we override the fuzz to 0 */
+	ck_assert_int_eq(abs->fuzz, 0);
+}
+END_TEST
+
 TEST_COLLECTION(misc)
 {
 	litest_add_no_device("events:conversion", event_conversion_device_notify);
@@ -780,4 +858,6 @@ TEST_COLLECTION(misc)
 	litest_add_no_device("timer:flush", timer_flush);
 
 	litest_add_no_device("misc:fd", fd_no_event_leak);
+
+	litest_add_for_device("misc:system", udev_absinfo_override, LITEST_ABSINFO_OVERRIDE);
 }
